module Hikki
  module Adapters
    class MemcacheCollection < Hikki::Collection
      attr_reader :connection, :uuid_generator

      def initialize(collection, connection, uuid_generator)
        super(collection)
        @connection = connection
        @uuid_generator = uuid_generator
      end

      def index(field)
        false
      end

      def save(data)
        data = normalize_data(data)
        connection.set(key(data['id']), data)
        data
      end

      def find(id)
        connection.get(key(id)) || {}
      end

      def all(options={})
        []
      end

      def find_by(field, value, options={})
        []
      end

      def remove(id)
        connection.delete(key(id))
        true
      end

      def remove_all
        connection.flush
      end

      def id_for(data)
        data.fetch('id', uuid_generator.uuid).to_s
      end

      private
      def key(id)
        collection + ':' + id.to_s
      end

    end
  end
end